library text_form_field_validator;

class FormValidator {
  //validator static method
  static String? validate(data,
      {bool required = false,
      String requiredMessage = "Field cannot be empty",
      int min = 0,
      String minMessage = "Data must be of % length",
      int max = 20000,
      String maxMessage = "Data must not exceed % characters",
      String? match,
      String matchMessage = "%data doesn't match with %match",
      RegExp? regex,
      String regexMessage = "Invalid input!",
      StringFormat? stringFormat,
      String? stringFormatMessage}) {
    String? _errorMsg;
    if (required == true) {
      if (data == null || data.isEmpty) {
        _errorMsg ??= requiredMessage;
      }
    }

    if (min != 0) {
      if (min > data.length) {
        _errorMsg ??= minMessage.replaceAll('%', '$min');
      }
    }
    if (max != 20000) {
      if (max < data.length) {
        _errorMsg ??= maxMessage.replaceAll('%', '$max');
      }
    }

    if (match != null) {
      if (data != match) {
        _errorMsg ??= matchMessage
            .replaceAll('%data', '$data')
            .replaceAll('%match', '$match');
      }
    }

    if (stringFormat != null) {
      if (stringFormat == StringFormat.email) {
        if (!RegExp(
                r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+")
            .hasMatch(data)) {
          _errorMsg = stringFormatMessage ?? "Invalid email";
        }
      }
      if (stringFormat == StringFormat.url) {
        if (!RegExp(r"^http[s]?:\/\/(www\.)?(.*)?\/?(.)*").hasMatch(data)) {
          _errorMsg = stringFormatMessage ?? "Invalid url";
        }
      }
      if (stringFormat == StringFormat.numbers) {
        if (!RegExp(r"^[0-9]*$").hasMatch(data)) {
          _errorMsg = stringFormatMessage ?? "Invalid Number";
        }
      }
    }

    if (regex != null) {
      if (!regex.hasMatch(data)) {
        _errorMsg ??= regexMessage;
      }
    }

    return _errorMsg;
  }
}

enum StringFormat { email, url, numbers }
