import 'package:test/test.dart';
import 'package:text_form_field_validator/text_form_field_validator.dart';

void main() {
  group("required", () {
    test("required = true", () {
      String? errMsg = FormValidator.validate(
        "",
        required: true,
      );
      expect(errMsg, "Field cannot be empty");
    });

    test("required : true, requiredMessege : Cannot be empty", () {
      String? errMsg = FormValidator.validate(
        "",
        required: true,
        requiredMessage: "Cannot be empty",
      );
      expect(errMsg, "Cannot be empty");
    });

    test("required: not provided", () {
      String? errMsg = FormValidator.validate("");
      expect(errMsg, null);
    });
  });

  group("min", () {
    test("min: 4", () {
      String? errMsg = FormValidator.validate(
        "hi",
        min: 4,
      );
      expect(errMsg, "Data must be of 4 length");
    });
    test("min: 6, minMessage: Must contain % characters", () {
      String? errMsg = FormValidator.validate(
        "hel",
        min: 6,
        minMessage: "Must contain % characters",
      );
      expect(errMsg, "Must contain 6 characters");
    });
    test("min: not provided", () {
      String? errMsg = FormValidator.validate(
        "he",
      );
      expect(errMsg, null);
    });
  });

  group("max", () {
    test("min: 4", () {
      String? errMsg = FormValidator.validate(
        "abcdefg",
        max: 4,
      );
      expect(errMsg, "Data must not exceed 4 characters");
    });
    test("max: 6, maxMessage: Must not exceed % characters", () {
      String? errMsg = FormValidator.validate(
        "abcdefghij",
        max: 6,
        maxMessage: "% are too much characters",
      );
      expect(errMsg, "6 are too much characters");
    });
    test("max: not provided", () {
      String? errMsg = FormValidator.validate(
        "The brown fox quickly jump over the lazy dog",
      );
      expect(errMsg, null);
    });
  });

  group("match", () {
    test('match: "boo"', () {
      String? errMsg = FormValidator.validate(
        "boo",
        match: "boob",
      );
      expect(errMsg, "boo doesn't match with boob");
    });

    test('match: "boo", matchMessage: "%data does not match with %match"', () {
      String? errMsg = FormValidator.validate("boo",
          match: "boob", matchMessage: "%data does not match with %match");
      expect(errMsg, "boo does not match with boob");
    });

    test('match: "boob", matchMessage: "%data does not match with %match"', () {
      String? errMsg = FormValidator.validate("boob",
          match: "boob", matchMessage: "%data does not match with %match");
      expect(errMsg, null);
    });
  });

  group("regex", () {
    test('regex: a valid regex can not type here', () {
      String? errMsg = FormValidator.validate(
        "123a",
        regex: RegExp(r"^[0-9]*$"),
      );
      expect(errMsg, "Invalid input!");
    });

    test('regex: a valid regex, regexMessage: "Not a valid input"', () {
      String? errMsg = FormValidator.validate(
        "123a",
        regex: RegExp(r"^[0-9]*$"),
        regexMessage: "Not a valid input",
      );
      expect(errMsg, "Not a valid input");
    });

    test('regex: a valid regex', () {
      String? errMsg = FormValidator.validate(
        "123",
        regex: RegExp(r"^[0-9]*$"),
      );
      expect(errMsg, null);
    });
  });

  group("stringFormat: ", () {
    test("stringFormat: StringFormat.email", () {
      //Assert
      expect(FormValidator.validate("niamul", stringFormat: StringFormat.email),
          "Invalid email");
      expect(FormValidator.validate("niamulhasanbd@gmail.com"), null);
    });

    test("stringFormat: StringFormat.url", () {
      //Assert
      expect(FormValidator.validate("niamul", stringFormat: StringFormat.url),
          "Invalid url");
      expect(FormValidator.validate("http://startbit.com"), null);
    });

    test("stringFormat: StringFormat.number", () {
      //Assert
      expect(FormValidator.validate("123a", stringFormat: StringFormat.numbers),
          "Invalid Number");
      expect(FormValidator.validate("1234"), null);
    });
  });
}
